@@ -14,13 +14,11 @@ RObject impl_multcomp_pmt(
     auto multcomp_update = [&statistic_container, &statistic_func, group_i, group_j, data, group, K]() {
         auto statistic_closure = statistic_func(data, group);
 
-        for (R_xlen_t k = 0; k < K; k++) {
-            if (!(statistic_container << statistic_closure(group_i[k], group_j[k]))) {
-                return false;
-            }
-        };
+        for (R_xlen_t k = 0; k < K - 1; k++) {
+            statistic_container << statistic_closure(group_i[k], group_j[k]);
+        }
 
-        return true;
+        return statistic_container << statistic_closure(group_i[K - 1], group_j[K - 1]);
     };
 
     if (std::isnan(n_permu)) {
